==> buildfile_1.0.0_for_2.1_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/listener/ProjectTreeMouseListener.java <==
/*
 * 2004-10-24 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.listener;

import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.data.Data;
import org.vivianj.eclipse.plugin.buildfile.data.Project;
import org.vivianj.eclipse.plugin.buildfile.data.target.Target;
import org.vivianj.eclipse.plugin.buildfile.util.Resource;
import org.vivianj.eclipse.plugin.buildfile.util.ShellFactory;

/**
 * ProjectTreeMouseListenerʵTreeҼ¼
 */
public class ProjectTreeMouseListener implements MouseListener {
	/** Ұ벿ʾ */
	private Group group;

	private TreeItem selection = null;

	private TextEditor editor = null;

	public ProjectTreeMouseListener() {

	}

	/**
	 * ProjectTreeMouseListener
	 * 
	 * @param p_group
	 *            ڵʾʵ
	 * @param editor
	 *            ITextEditorʵ
	 */
	public ProjectTreeMouseListener(Group p_group, TextEditor editor) {
		this.group = p_group;
		this.editor = editor;
	}

	/*
	 * mouseDownTreeϵҼ¼
	 */
	public void mouseDown(MouseEvent arg0) {
		Tree tree = (Tree) arg0.getSource();
		TreeItem[] treeItems = tree.getSelection();
		TreeItem treeItem = null;
		//ûҼʱʾpopupMenus
		if (arg0.button == 3 && treeItems.length > 0) {
			treeItem = treeItems[0];
			Data data = (Data) treeItem.getData();
			if (data instanceof Project || data instanceof Target) {
				//ʾѡĵ
				Shell shell = new Shell(treeItem.getDisplay());
				shell.setText(Resource.getSource("shell.title"));

				//ݲͬĽڵʾͬĵ
				ShellFactory.createShell(data, shell, this.group, treeItem,
						this.editor);
				shell.open();
				shell.pack();
			}
		}
	}

	public void mouseUp(MouseEvent arg0) {
	}

	public void mouseDoubleClick(MouseEvent arg0) {
	}

}

==> buildfile_1.2.36_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/listener/ProjectTreeMouseListener.java <==
/*
 * 2004-10-24 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.listener;

import java.util.List;

import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.jdom.Element;
import org.vivianj.eclipse.plugin.buildfile.data.NodeData;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileTemplate;
import org.vivianj.eclipse.plugin.buildfile.util.Resource;
import org.vivianj.eclipse.plugin.buildfile.util.ShellFactory;

/**
 * ProjectTreeMouseListenerʵTreeҼ¼
 */
public class ProjectTreeMouseListener implements MouseListener {
	/** Ұ벿ʾ */
	private Group group;

	private TreeItem selection = null;

	private TextEditor editor = null;

	public ProjectTreeMouseListener() {

	}

	/**
	 * ProjectTreeMouseListener
	 * 
	 * @param p_group
	 *            ڵʾʵ
	 * @param editor
	 *            ITextEditorʵ
	 */
	public ProjectTreeMouseListener(Group p_group, TextEditor editor) {
		this.group = p_group;
		this.editor = editor;
	}

	/*
	 * mouseDownTreeϵҼ¼
	 */
	public void mouseDown(MouseEvent arg0) {
		Tree tree = (Tree) arg0.getSource();
		TreeItem[] treeItems = tree.getSelection();
		TreeItem treeItem = null;
		//ûҼʱʾpopupMenus
		if (arg0.button == 3 && treeItems.length > 0) {
			treeItem = treeItems[0];
			NodeData data = (NodeData) treeItem.getData();
			String path = data.getPath();

			BuildFileTemplate builFile = new BuildFileTemplate();
			Element element = builFile.getElementByPath(path);
			List list = element.getChildren();
			if (list.size() > 0) {
				//ʾѡĵ
				Shell shell = new Shell(treeItem.getDisplay());
				shell.setText(Resource.getSource("shell.title"));

				//ݲͬĽڵʾͬĵ
				ShellFactory.createShell(data, shell, this.group, treeItem,
						this.editor);
				shell.open();
				shell.pack();
			}

		}
	}

	public void mouseUp(MouseEvent arg0) {
	}

	public void mouseDoubleClick(MouseEvent arg0) {
	}

}
